searchData={"items":[{"type":"module","title":"Hangman.Game","doc":"A game struct and functions for the _Hangman Game_.\n\nThe game struct contains the fields `game_name`, `game_state`, `turns_left`,\n`letters` and `used` representing the properties of a game in the _Hangman\nGame_.\n\n##### Based on the course [Elixir for Programmers](https://codestool.coding-gnome.com/courses/elixir-for-programmers) by Dave Thomas.","ref":"Hangman.Game.html"},{"type":"type","title":"Hangman.Game.letter/0","doc":"Letter from `a` to `z`","ref":"Hangman.Game.html#t:letter/0"},{"type":"function","title":"Hangman.Game.make_move/2","doc":"Makes a move by guessing a letter.","ref":"Hangman.Game.html#make_move/2"},{"type":"function","title":"Examples - Hangman.Game.make_move/2","doc":"iex> alias Hangman.Game\n    iex> game = Game.new(\"wibble\")\n    iex> Game.make_move(game, \"a\").game_state\n    :bad_guess\n\n    iex> alias Hangman.Game\n    iex> game = Game.new(\"wibble\")\n    iex> Game.make_move(game, \"B\")\n    ** (ArgumentError) guess 'B' not a-z","ref":"Hangman.Game.html#make_move/2-examples"},{"type":"type","title":"Hangman.Game.name/0","doc":"Game name","ref":"Hangman.Game.html#t:name/0"},{"type":"function","title":"Hangman.Game.new/2","doc":"Creates a game struct from a `word` to be guessed and a `game_name`.\nThe default value for `game_name` is provided by function `random_name/0`.\n\nUsing function `Hangman.Dictionary.random_word/0` of app `:hangman_dictionary`\nto provide the default value for `word` would cause app `:hangman_dictionary`\nto run on each client node as opposed to only on the engine node (see function\n`Hangman.Engine.GameServer.init/1` of app [:hangman_engine][he]).\n\n[he]: https://hex.pm/packages/hangman_engine","ref":"Hangman.Game.html#new/2"},{"type":"function","title":"Examples - Hangman.Game.new/2","doc":"iex> alias Hangman.Game\n    iex> %Game{game_name: name} = game = Game.new(\"wibble\", \"Wibble\")\n    iex> {name, game.game_state, game.turns_left, game.letters, game.used}\n    {\"Wibble\", :initializing, 7, ~W[w i b b l e], MapSet.new([])}\n\n    iex> alias Hangman.Game\n    iex> Game.new(\"José\")\n    ** (ArgumentError) some characters of 'José' not a-z","ref":"Hangman.Game.html#new/2-examples"},{"type":"function","title":"Hangman.Game.random_name/0","doc":"Returns a random name of 4 to 10 characters.","ref":"Hangman.Game.html#random_name/0"},{"type":"function","title":"Examples - Hangman.Game.random_name/0","doc":"iex> alias Hangman.Game\n    iex> for _ <- 0..99, uniq: true do\n    iex>   length = Game.random_name() |> String.length()\n    iex>   length in 4..10\n    iex> end\n    [true]\n\n    iex> alias Hangman.Game\n    iex> for _ <- 0..99, uniq: true do\n    iex>   Game.random_name() =~ ~r/^[a-zA-Z0-9_-]{4,10}$/\n    iex> end\n    [true]","ref":"Hangman.Game.html#random_name/0-examples"},{"type":"function","title":"Hangman.Game.resign/1","doc":"Resigns `game`.","ref":"Hangman.Game.html#resign/1"},{"type":"function","title":"Examples - Hangman.Game.resign/1","doc":"iex> alias Hangman.Game\n    iex> game = Game.new(\"anaconda\")\n    iex> game = Game.make_move(game, \"a\")\n    iex> game = Game.make_move(game, \"n\")\n    iex> lost_game = Game.resign(game)\n    iex> tally = Game.tally(lost_game)\n    iex> {tally.game_state, tally.turns_left, tally.letters, tally.guesses}\n    {:lost, 7, [\"a\", \"n\", \"a\", [\"c\"], [\"o\"], \"n\", [\"d\"], \"a\"], ~W[a n]}","ref":"Hangman.Game.html#resign/1-examples"},{"type":"type","title":"Hangman.Game.state/0","doc":"Game state","ref":"Hangman.Game.html#t:state/0"},{"type":"type","title":"Hangman.Game.t/0","doc":"A game struct for the Hangman Game","ref":"Hangman.Game.html#t:t/0"},{"type":"type","title":"Hangman.Game.tally/0","doc":"A tally map for the Hangman Game","ref":"Hangman.Game.html#t:tally/0"},{"type":"function","title":"Hangman.Game.tally/1","doc":"Returns a tally map externalizing `game`.","ref":"Hangman.Game.html#tally/1"},{"type":"function","title":"Examples - Hangman.Game.tally/1","doc":"iex> alias Hangman.Game\n    iex> game = Game.new(\"anaconda\")\n    iex> game = Game.make_move(game, \"a\")\n    iex> game = Game.make_move(game, \"n\")\n    iex> tally = Game.tally(game)\n    iex> {tally.game_state, tally.turns_left, tally.letters, tally.guesses}\n    {:good_guess, 7, ~W[a n a _ _ n _ a], ~W[a n]}","ref":"Hangman.Game.html#tally/1-examples"},{"type":"type","title":"Hangman.Game.turns_left/0","doc":"Turns left from 7 to 0","ref":"Hangman.Game.html#t:turns_left/0"},{"type":"type","title":"Hangman.Game.underline/0","doc":"Underline: `_`","ref":"Hangman.Game.html#t:underline/0"},{"type":"type","title":"Hangman.Game.used/0","doc":"A set of used (guessed) letters","ref":"Hangman.Game.html#t:used/0"},{"type":"type","title":"Hangman.Game.word/0","doc":"A word with letters from `a` to `z`","ref":"Hangman.Game.html#t:word/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}